@@ -36,7 +36,9 @@
 namespace Kerfuffle
 {
 ReadOnlyArchiveInterface::ReadOnlyArchiveInterface(QObject *parent, const QVariantList & args)
-        : QObject(parent), m_waitForFinishedSignal(false)
+        : QObject(parent),
+          m_waitForFinishedSignal(false),
+          m_isHeaderEncryptionEnabled(false)
 {
     qCDebug(KERFUFFLE) << "Created read-only interface for" << args.first().toString();
     m_filename = args.first().toString();
