@@ -28,7 +28,7 @@
 #ifndef ARCHIVEINTERFACE_H
 #define ARCHIVEINTERFACE_H
 
-#include "archive.h"
+#include "archive_kerfuffle.h"
 #include "kerfuffle_export.h"
 
 #include <QObject>
@@ -73,6 +73,7 @@ public:
      */
     virtual bool list() = 0;
     void setPassword(const QString &password);
+    void setHeaderEncryptionEnabled(bool enabled);
 
     /**
      * Extract files from archive.
@@ -94,6 +95,7 @@ public:
     virtual bool doResume();
 
 signals:
+    void cancelled();
     void error(const QString &message, const QString &details = QString());
     void entry(const ArchiveEntry &archiveEntry);
     void entryRemoved(const QString &path);
@@ -112,10 +114,13 @@ protected:
      */
     void setWaitForFinishedSignal(bool value);
 
+    bool isHeaderEncryptionEnabled() const;
+
 private:
     QString m_filename;
     QString m_password;
     bool m_waitForFinishedSignal;
+    bool m_isHeaderEncryptionEnabled;
 };
 
 class KERFUFFLE_EXPORT ReadWriteArchiveInterface: public ReadOnlyArchiveInterface
@@ -125,7 +130,7 @@ public:
     explicit ReadWriteArchiveInterface(QObject *parent, const QVariantList & args);
     virtual ~ReadWriteArchiveInterface();
 
-    virtual bool isReadOnly() const;
+    bool isReadOnly() const Q_DECL_OVERRIDE;
 
     //see archive.h for a list of what the compressionoptions might
     //contain
