@@ -20,21 +20,26 @@
  *
  */
 
+#include "plugins/logging_kerfuffle_plugin.h"
 #include "cliplugin.h"
 #include "kerfuffle/kerfuffle_export.h"
 
-#include <kdebug.h>
-
+#include <QDebug>
 #include <QDir>
 #include <QDate>
 #include <QTime>
 
+Q_LOGGING_CATEGORY(KERFUFFLE_PLUGIN, "ark.kerfuffle.cliexample", QtWarningMsg)
+
+K_PLUGIN_FACTORY( CliPluginFactory, registerPlugin< CliPlugin >(); )
+
 CliPlugin::CliPlugin(QObject *parent, const QVariantList &args)
     : CliInterface(parent, args),
       m_isFirstLine(true),
       m_incontent(false),
       m_isPasswordProtected(false)
 {
+    qCDebug(KERFUFFLE_PLUGIN) << "Loaded cli-example plugin";
 }
 
 CliPlugin::~CliPlugin()
@@ -124,7 +129,7 @@ bool CliPlugin::readListLine(const QString &line)
         m_entryFilename += QLatin1Char('/');
     }
 
-    //kDebug() << m_entryFilename << " : " << fileprops;
+    qCDebug(KERFUFFLE_PLUGIN) << m_entryFilename << " : " << fileprops;
     ArchiveEntry e;
     e[ FileName ] = m_entryFilename;
     e[ InternalID ] = m_internalId;
@@ -138,11 +143,11 @@ bool CliPlugin::readListLine(const QString &line)
     e[ Method ] = fileprops[ 7 ];
     e[ Version ] = fileprops[ 8 ];
     e[ IsPasswordProtected] = m_isPasswordProtected;
-    kDebug() << "Added entry: " << e;
+    qCDebug(KERFUFFLE_PLUGIN) << "Added entry: " << e;
 
     emit entry(e);
     m_isFirstLine = true;
     return true;
 }
 
-KERFUFFLE_EXPORT_PLUGIN(CliPlugin)
+#include "cliplugin.moc"
