@@ -24,10 +24,14 @@
  */
 
 #include "xzplugin.h"
-#include "kerfuffle/kerfuffle_export.h"
+#include "kerfuffle_export.h"
 
 #include <QString>
 
+#include <KPluginFactory>
+
+K_PLUGIN_FACTORY( XzPluginFactory, registerPlugin< LibXzInterface >(); )
+
 LibXzInterface::LibXzInterface(QObject *parent, const QVariantList & args)
         : LibSingleFileInterface(parent, args)
 {
@@ -40,6 +44,4 @@ LibXzInterface::~LibXzInterface()
 {
 }
 
-KERFUFFLE_EXPORT_PLUGIN(LibXzInterface)
-
 #include "xzplugin.moc"
